Calculate non-thresholded diadromous DCI
calculate_dci_dia(
all_members,
net_nodes,
seg_weights,
outlet_seg,
parallel,
quiet
)A data frame which holds raw and relative DCI scores for each segment.
An integer vector holding all assigned membership labels
in the river_net object.
An sf object of the nodes of the
river_net
object with river attributes joined.
A data frame of each segments total length. Either weighted or unweighted depending on parameters.
An integer indicating the membership label of the outlet segment
Logical. If FALSE, the default, all operations are
performed in series. If TRUE parallel operation is performed using
furrr::future_pmap(). Specify the number of workers and strategy using
future::plan().
Logical. If FALSE, prints the global DCI and a plot of river
segments to the console. Defaults to TRUE.