Correct river divergences
correct_divergences(net, correct = TRUE, quiet = FALSE)If correct is TRUE a river_net object with the shorter of each divergent pair removed. If correct is FALSE a sf object with divergent pairs identified with a shared number in the new "divergent" column.
A river_net object.
Logical. If FALSE (default), no changes are made and
topological issues are identified only. If TRUE, issues are
automatically corrected.
Logical. If FALSE, prints the global DCI and a plot of river
segments to the console. Defaults to TRUE.