Calculate thresholded invasive DCI
gather_dci(
net,
form,
from,
to,
distance,
pass,
nodes,
seg_weights,
threshold,
totweight,
weighted
)A data frame which holds raw and relative DCI scores for each segment.
A river_net object.
A string specifying the DCI form to calculate. Options are: "pot" for potamodromous or "dia" for diadromous.
The name of a column in the nodes table of net containing
numeric passability values. If NULL, all barriers are assumed to have 0
passability.
Optional numeric value specifying a dispersal limit in map
units. If NULL (default), no limit is applied.
The total length or weighted length of the whole network.
A logical value indicating whether river lengths in seg_weights are weighted.