A spatial river_net object extending the tidygraph representation of
spatial graphs. Nodes represent confluences, river endpoints, barriers, and
the outlet. Edges represent stream reaches. Spatial features are projected to
EPSG:32198.
yamaska_netA river_net object with:
the geometry list column of the node point features
the passability of nodes in the network from 0 (impassable) to 1
the binary passability of nodes in the network, 0 if a barrier and 1 otherwise
the type of the node: topological, barrier, or outlet
the row index of the origin node of the edge feature
the row index of the destination node of the edge feature
a simulated weighting based on habitat quality of features
length of edge features in meters
unique river feature integer ID
the geometry list column of edge line features