gather_dist: Gather total distance between two nodes
Description
Gather total distance between two nodes
Usage
gather_dist(from, to, nodes)
Value
The distance, in map units, between the two given segments.
Arguments
- from
The from node's label
- to
The to node's label
- nodes
An sf object of the nodes of the river_net object with river attributes joined.